@@ -36,47 +36,43 @@ SphinxControl::SphinxControl(const QString& username, QObject* parent) : Recogni
 
 bool SphinxControl::initializeRecognition(const QString &modelPath)
 {
-  if (modelPath == m_lastModel) return true; //already initialized / tried to initialize with this exact model
-
-  m_lastModel = modelPath;
-  kDebug() << "Initializing";
-  if (isInitialized())
-  {
-    kDebug() << "Initializing recognition that was already initialized; uninitializing...";
+  kDebug() << "Initializing to " << modelPath << m_lastModel;
+  if (modelPath != m_lastModel) { //already initialized / tried to initialize with this exact model
+    m_lastModel = modelPath;
+    kDebug() << "Initializing";
     uninitialize();
     m_startRequests = 0;
+
+    QString path = KStandardDirs::locateLocal("tmp", "/simond/"+username+"/sphinx/");
+    if(!QDir(path).entryInfoList(QDir::NoDotAndDotDot | QDir::System | QDir::Hidden  | QDir::AllDirs | QDir::Files, QDir::DirsFirst).isEmpty())
+    {
+      kDebug() << "Removing old data from working dir";
+      FileUtils::removeDirRecursive(path);
+      path = KStandardDirs::locateLocal("tmp", "/simond/"+username+"/sphinx/");
+    }
+
+    kDebug() << "Unpacking model to working dir";
+    if (!FileUtils::unpackAll(modelPath, path))
+    {
+      return false;
+    }
+
+    QFile metadataFile(path+QLatin1String("metadata.xml"));
+    if(!metadataFile.open(QIODevice::ReadOnly))
+    {
+      emit recognitionError(i18n("Failed to read metadata from \"%1\"", path+QLatin1String("metadata.xml")),
+                            getBuildLog());
+      return NULL;
+    }
+    ModelMetadata metadata;
+    QDomDocument DomDocument;
+    DomDocument.setContent(&metadataFile);
+    metadata.deserializeXml(DomDocument.documentElement());
+
+    metadataFile.close();
+
+    modelName = metadata.name();
   }
-
-  QString path = KStandardDirs::locateLocal("tmp", "/simond/"+username+"/sphinx/");
-  if(!QDir(path).entryInfoList(QDir::NoDotAndDotDot | QDir::System | QDir::Hidden  | QDir::AllDirs | QDir::Files, QDir::DirsFirst).isEmpty())
-  {
-    kDebug() << "Removing old data from working dir";
-    FileUtils::removeDirRecursive(path);
-    path = KStandardDirs::locateLocal("tmp", "/simond/"+username+"/sphinx/");
-  }
-
-  kDebug() << "Unpacking model to working dir";
-  if (!FileUtils::unpackAll(modelPath, path))
-  {
-    return false;
-  }
-
-  QFile metadataFile(path+QLatin1String("metadata.xml"));
-  if(!metadataFile.open(QIODevice::ReadOnly))
-  {
-    emit recognitionError(i18n("Failed to read metadata from \"%1\"", path+QLatin1String("metadata.xml")),
-                          getBuildLog());
-    return NULL;
-  }
-  ModelMetadata metadata;
-  QDomDocument DomDocument;
-  DomDocument.setContent(&metadataFile);
-  metadata.deserializeXml(DomDocument.documentElement());
-
-  metadataFile.close();
-
-  modelName = metadata.name();
-
   kDebug() << "Emitting recognition ready";
   emit recognitionReady();
   return true;
