@@ -29,7 +29,7 @@
 #  define SIMONRECOGNIZER_EXPORT KDE_EXPORT
 # else
 // We are using this library
-#  define SIMONRECOGNIZER_EXPORT
+#  define SIMONRECOGNIZER_EXPORT KDE_IMPORT
 # endif
 #endif
 
