@@ -348,12 +348,14 @@ LanguageDescriptionContainer* ModelManager::getLanguageDescriptionContainer()
   QFile shadowVocab(KStandardDirs::locate("appdata", "shadowvocabulary.xml"));
   QFile languageProfile(KStandardDirs::locate("appdata", "model/languageProfile"));
 
-  languageProfile.open(QIODevice::ReadOnly); //optional, so we don't care if that doesn't exist - readAll works fine
-
   if (!shadowVocab.open(QIODevice::ReadOnly))
     return 0;
 
-  return new LanguageDescriptionContainer(shadowVocab.readAll(), languageProfile.readAll());
+  QByteArray languageP;
+  if (languageProfile.open(QIODevice::ReadOnly))
+    languageP += languageProfile.readAll();
+
+  return new LanguageDescriptionContainer(shadowVocab.readAll(), languageP);
 }
 
 
@@ -460,7 +462,7 @@ bool ModelManager::storeSample(const QString& name, const QByteArray& sample)
 {
   QString dirPath = TrainingManager::getInstance()->getTrainingDir()+'/';
 
-  QFile f(dirPath+name+".wav");
+  QFile f(dirPath+name);
   if (!f.open(QIODevice::WriteOnly)) return false;
 
   f.write(sample);
