@@ -66,9 +66,10 @@ bool ModelCompilationAdapterSPHINX::startAdaption(AdaptionType adaptionType, con
   //merging scenarios
   mergeInputData(scenarioPathsIn, mergedVocabulary, mergedGrammar);
 
-  if((adaptionType & ModelCompilationAdapter::AdaptLanguageModel) &&  mergedVocabulary->empty())
+  if ((adaptionType & ModelCompilationAdapter::AdaptLanguageModel) &&
+      (mergedVocabulary->empty() || (mergedGrammar->structureCount() == 0)))
   {
-    kDebug()<<"Empty vocabulary aborting adaptation";
+    kDebug() << "Empty vocabulary or grammar; aborting adaptation";
     emit adaptionAborted(ModelCompilation::InsufficientInput);
     return false;
   }
@@ -117,9 +118,12 @@ bool ModelCompilationAdapterSPHINX::storeModel(AdaptionType adaptionType, const
   QString fetc = workingDirPath+"/"+mName+"/etc/"+mName;
 
   kDebug()<<"Store dictionary";
-  if(!purgeUnusedVocabulary(vocabulary, grammar) ||
-     !storeDictionary(adaptionType, fetc+DICT_EXT, trainedVocabulary, definedVocabulary,
-                      vocabulary))
+
+  bool errorStoringDictionary = !storeDictionary(adaptionType, fetc+DICT_EXT, fetc+QLatin1String("_ship")+DICT_EXT,
+                                                 trainedVocabulary, definedVocabulary,
+                                                 vocabulary);
+
+  if(!purgeUnusedVocabulary(vocabulary, grammar) || errorStoringDictionary)
   {
     emit error(i18n("Failed to store dictionary"));
     return false;
@@ -130,14 +134,16 @@ bool ModelCompilationAdapterSPHINX::storeModel(AdaptionType adaptionType, const
   kDebug()<<"Store filler";
   if(!storeFiller(adaptionType, fetc+".filler"))
   {
-    emit error(i18n("Failed to store filler"));
+    emit error(i18nc("Please keep \"filler\" in English as it refers to a file that is usually named that",
+                     "Failed to store filler"));
     return false;
   }
 
   ADAPT_CHECKPOINT;
 
   kDebug()<<"Store phonelist";
-  if(!(adaptionType == ModelCompilationAdapter::AdaptLanguageModel) && !storePhonesList(adaptionType, fetc+PHONE_EXT, vocabulary, trainedVocabulary))
+  if(!(adaptionType == ModelCompilationAdapter::AdaptLanguageModel) &&
+     !storePhonesList(adaptionType, fetc+PHONE_EXT, vocabulary, trainedVocabulary))
   {
     emit error(i18n("Failed to store phones"));
     return false;
@@ -145,15 +151,21 @@ bool ModelCompilationAdapterSPHINX::storeModel(AdaptionType adaptionType, const
 
   ADAPT_CHECKPOINT;
 
-  kDebug()<<"Store transcription & fields";
-  if(!(adaptionType == ModelCompilationAdapter::AdaptLanguageModel) &&
-     (!storeTranscriptionAndFields(adaptionType, promptsPathIn, fetc+TRAIN_TRANSCRIPTION, fetc+TRAIN_FIELDS,
-         definedVocabulary, vocabulary)
-      || !storeTranscriptionAndFields(adaptionType, promptsPathIn,
-         fetc+TEST_TRANSCRIPTION, fetc+TEST_FIELDS, definedVocabulary, vocabulary)))
-  {
-    emit error(i18n("Failed to store transcription and fields"));
-    return false;
+  if (adaptionType & ModelCompilationAdapter::AdaptAcousticModel) {
+    kDebug()<<"Store transcription & fields";
+    bool err = storeTranscriptionAndFields(adaptionType, promptsPathIn,
+                                                            fetc+TRAIN_TRANSCRIPTION,
+                                                            fetc+TRAIN_FIELDS,
+                                                            definedVocabulary);
+
+    err = err && storeTranscriptionAndFields(adaptionType, promptsPathIn,
+                                                                fetc+TEST_TRANSCRIPTION,
+                                                                fetc+TEST_FIELDS,
+                                                                definedVocabulary);
+    if (!err) {
+        kDebug() << "Returning here; store transcription and fields failed...?";
+        return false; // error reporting done by the function itself
+    }
   }
 
   ADAPT_CHECKPOINT;
@@ -170,50 +182,70 @@ bool ModelCompilationAdapterSPHINX::storeModel(AdaptionType adaptionType, const
 
 bool ModelCompilationAdapterSPHINX::purgeUnusedVocabulary(QSharedPointer<Vocabulary> vocabulary, QSharedPointer<Grammar> grammar)
 {
-  QSet<QString> terminals;
+  QSet<QString> categories;
   foreach (const QString& structure, grammar->getStructures())
-    foreach (const QString& terminal, structure.split(" ", QString::SkipEmptyParts))
-      terminals.insert(terminal);
+    foreach (const QString& category, structure.split(" ", QString::SkipEmptyParts))
+      categories.insert(category);
   QList<Word*> words = vocabulary->getWords();
   foreach (Word* w, words)
-    if (!terminals.contains(w->getTerminal()))
+    if (!categories.contains(w->getCategory()))
       vocabulary->removeWord(w);
   return true;
 }
 
-bool ModelCompilationAdapterSPHINX::storeDictionary(AdaptionType adaptionType, const QString &dictionaryPathOut, QStringList &trainedVocabulary,
+bool ModelCompilationAdapterSPHINX::storeDictionary(AdaptionType adaptionType, const QString &dictionaryPathTrainOut, const QString &dictionaryPathOut, QStringList &trainedVocabulary,
                                                     QStringList &definedVocabulary, QSharedPointer<Vocabulary> vocabulary)
 {
   QFile dictionaryFile(dictionaryPathOut);
-  if (!dictionaryFile.open(QIODevice::WriteOnly))
+  QFile dictionaryTrainFile(dictionaryPathTrainOut);
+  if (!dictionaryFile.open(QIODevice::WriteOnly) || !dictionaryTrainFile.open(QIODevice::WriteOnly) )
   {
+    //FIXME: After string freeze, add dictioanryPathTrainOut
     emit error(i18n("Failed to adapt dictionary to \"%1\"", dictionaryPathOut));
     return false;
   }
 
   QTextStream dictionary(&dictionaryFile);
+  QTextStream dictionaryTrain(&dictionaryTrainFile);
   dictionary.setCodec("UTF-8");
+  dictionaryTrain.setCodec("UTF-8");
 
   m_pronunciationCount = 0;
   QList<Word*> words = vocabulary->getWords();
 
-  QStringList added; //Think about better way to do it
   m_wordCount = 0;
+  QHash<QString, int> wordCounts;
+  QHash<QString, int> wordCountsShip;
   foreach (Word *word, words)
   {
     if ((adaptionType & ModelCompilationAdapter::AdaptAcousticModel) &&
             (!(adaptionType == ModelCompilationAdapter::AdaptIndependently) &&
-        (!trainedVocabulary.contains(word->getLexiconWord()) || added.contains(word->getWord()))))
+        (!trainedVocabulary.contains(word->getLexiconWord()))))
     {
       kDebug() << "Skipping word " << word->getWord();
       continue;
     }
 
     ++m_pronunciationCount;
-    dictionary << word->getWord() << QLatin1String("\t\t") <<
-                  word->getPronunciation() << QLatin1String("\n");
 
-    added.append(word->getWord());
+    QString wordName = word->getWord();
+    QString wordNameShip = word->getLexiconWord();
+    if (wordCounts.contains(wordName)) {
+      int currentCount = wordCounts.value(wordName) + 1;
+      wordCounts.insert(wordName, currentCount);
+      wordName += '(' + QByteArray::number(currentCount) + ')';
+    } else
+      wordCounts.insert(wordName, 1);
+    if (wordCountsShip.contains(wordNameShip)) {
+      int currentCount = wordCountsShip.value(wordNameShip) + 1;
+      wordCountsShip.insert(wordNameShip, currentCount);
+      wordNameShip += '(' + QByteArray::number(currentCount) + ')';
+    } else
+      wordCountsShip.insert(wordNameShip, 1);
+    dictionary << wordName << QLatin1String("\t\t") <<
+                  word->getPronunciation() << QLatin1String("\n");
+    dictionaryTrain << wordNameShip << QLatin1String("\t\t") <<
+                  word->getPronunciation() << QLatin1String("\n");
 
     ++m_wordCount;
     if (//(adaptionType == ModelCompilationAdapter::AdaptAcousticModel) &&
@@ -232,7 +264,8 @@ bool ModelCompilationAdapterSPHINX::storeFiller(AdaptionType adaptionType, const
   QFile fillerFile(fillerPathOut);
   if (!fillerFile.open(QIODevice::WriteOnly))
   {
-    emit error(i18n("Failed to write filler to \"%1\"", fillerPathOut));
+    emit error(i18nc("Please keep \"filler\" in English as it refers to a file that is usually named that",
+                     "Failed to write filler to \"%1\"", fillerPathOut));
     return false;
   }
 
@@ -249,7 +282,8 @@ bool ModelCompilationAdapterSPHINX::storeFiller(AdaptionType adaptionType, const
 }
 
 bool ModelCompilationAdapterSPHINX::storePhonesList(AdaptionType adaptionType, const QString &phonesListPathOut,
-                                                    QSharedPointer<Vocabulary> vocabulary, const QStringList &trainedVocabulary)
+                                                    QSharedPointer<Vocabulary> vocabulary,
+                                                    const QStringList &trainedVocabulary)
 {
   QFile phoneFile(phonesListPathOut);
   if (!phoneFile.open(QIODevice::WriteOnly))
@@ -290,8 +324,11 @@ bool ModelCompilationAdapterSPHINX::storePhonesList(AdaptionType adaptionType, c
   return true;
 }
 
-bool ModelCompilationAdapterSPHINX::storeTranscriptionAndFields(AdaptionType adaptionType, const QString &promptsPathIn, const QString &transcriptionPathOut,
-                                                                const QString &fieldsPathOut, QStringList &definedVocabulary, QSharedPointer<Vocabulary> vocabulary)
+bool ModelCompilationAdapterSPHINX::storeTranscriptionAndFields(AdaptionType adaptionType,
+                                                                const QString &promptsPathIn,
+                                                                const QString &transcriptionPathOut,
+                                                                const QString &fieldsPathOut,
+                                                                QStringList &definedVocabulary)
 {
   QFile promptsInFile(promptsPathIn);
   QFile promptsOutFile(transcriptionPathOut);
@@ -310,33 +347,29 @@ bool ModelCompilationAdapterSPHINX::storeTranscriptionAndFields(AdaptionType ada
     QString line = QString::fromUtf8(promptsInFile.readLine());
     int splitter = line.indexOf(" ");
     bool allWordsInLexicon = true;
-    QStringList words = line.mid(splitter+1).trimmed().split(' ');
+    QString sentence = line.mid(splitter+1).trimmed();
+    QStringList words = sentence.split(' ');
 
-    bool first(true);
-    QString wordsString;
     foreach (const QString& word, words)
     {
       if (!definedVocabulary.contains(word))
       {
         allWordsInLexicon = false;
-//        break;
+        break;
       }
-      if(!first)
-        wordsString.append(" ");
-      else
-        first = false;
-
-      QList<Word*> findWords= vocabulary->findWords(word, Vocabulary::ExactMatch);
-      if(!findWords.isEmpty())
-        wordsString.append(findWords.first()->getWord());
-      else
-        wordsString.append(word.toLower());//WARNING: error or not?
     }
 
     if (allWordsInLexicon || !(adaptionType & AdaptLanguageModel) || (adaptionType & AdaptIndependently))
     {
-      promptsOutFile.write("<s> "+wordsString.toUtf8() + " </s> (" + line.left(splitter).toUtf8() /*filename*/+ ")\n");
-      fieldsOutFile.write(line.left(splitter).toUtf8() /*filename*/ + "\n");
+      QByteArray filename;
+#ifdef Q_OS_WIN
+      filename = line.left(splitter).toLocal8Bit();
+#else
+      filename = line.left(splitter).toUtf8();
+#endif
+
+      promptsOutFile.write("<s> "+ sentence.toUtf8() + " </s> (" + filename + ")\n");
+      fieldsOutFile.write(filename + "\n");
       ++m_sampleCount;
     }
   }
@@ -359,6 +392,14 @@ bool ModelCompilationAdapterSPHINX::storeGrammar(ModelCompilationAdapter::Adapti
     return false;
   }
 
+  QStringList grammarStructures = grammar->getStructures();
+
+  if (grammarStructures.isEmpty())
+  {
+    emit adaptionAborted(ModelCompilation::InsufficientInput); //no grammar
+    return false;
+  }
+
   QTextStream grammarStream(&grammarFile);
   grammarStream.setCodec("UTF-8");
 
@@ -366,38 +407,30 @@ bool ModelCompilationAdapterSPHINX::storeGrammar(ModelCompilationAdapter::Adapti
                  <<"grammar generalGrammar;\n";
   grammarStream<< "public <structure> = ";
 
-  QStringList grammarStructures = grammar->getStructures();
-
   kDebug()<<"Structures count:"<< grammarStructures.size();
 
   foreach (const QString& structure, grammarStructures)
   {
-    QStringList terminals = Grammar::getTerminalsForStructure(structure);
-    if(terminals.isEmpty())
+    QStringList categories = Grammar::getCategoriesForStructure(structure);
+    if(categories.isEmpty())
       continue;
 
-//    if(structure != grammarStructures.first())
-//    {
-//     grammarStream<<"| ";
-//    }
-
     QString gramBuffer;
 
-    kDebug()<<"Terminals count for structure "<<structure<<": "<<terminals.size();
-    foreach (const QString &terminal, terminals)
+    kDebug()<<"Categories count for structure "<<structure<<": "<<categories.size();
+    foreach (const QString &category, categories)
     {
       bool fword = true;
-      QList<Word*> wordsForTerminal = vocabulary->findWordsByTerminal(terminal);
+      QList<Word*> wordsForCategory = vocabulary->findWordsByCategory(category);
 
-      kDebug()<<"Words for terminal "<<terminal<<":"<<wordsForTerminal.size();
+      kDebug()<<"Words for category "<<category<<":"<<wordsForCategory.size();
 
-      if(wordsForTerminal.isEmpty())
+      if(wordsForCategory.isEmpty())
         continue;
 
       QString termBuffer;
-//      uint addedCount(0);
 
-      foreach (Word* word, wordsForTerminal)
+      foreach (Word* word, wordsForCategory)
       {
         if(!definedVocabulary.contains(word->getLexiconWord()) && adaptionType != AdaptIndependently)//WARNING: talk about adapt independently becouse of magic
           continue;
@@ -428,13 +461,6 @@ bool ModelCompilationAdapterSPHINX::storeGrammar(ModelCompilationAdapter::Adapti
       grammarStream<< "(" << gramBuffer <<") ";
 
     }
-
-//    grammarStream<<") ";
-//    if(structure != grammarStructures.last())
-//    {
-//      grammarStream<<"| ";
-//    }
-
   }
   grammarStream<<";\n";
   return true;
