@@ -37,11 +37,21 @@ bool ModelCompilerSPHINX::parseConfiguration()
 //  if(compilationType & ModelCompiler::CompileSpeechModel)//TODO: think and then put conditions back
 //  {
     //   (compilationType & ModelCompilerHTK::AdaptSpeechModel)) {
+#ifdef Q_OS_WIN32
+    QString python = KStandardDirs::findExe("python");
+    QString sphinxTrain = programGroup.readEntry("sphinxtrain", KUrl(KStandardDirs::findExe("sphinxtrain"))).toLocalFile();
+    m_SphinxTrain = '"' + python + "\" \"" + sphinxTrain + '"';
+#else
     m_SphinxTrain = programGroup.readEntry("sphinxtrain", KUrl(KStandardDirs::findExe("sphinxtrain"))).toLocalFile();
+#endif
 
-    kDebug()<<"SPhinxtrain exec: "<<m_SphinxTrain;
+    kDebug()<<"Sphinxtrain exec: "<<m_SphinxTrain;
 
+#ifdef Q_OS_WIN32
+    if (!QFile::exists(python) || !QFile::exists(sphinxTrain))
+#else
     if (!QFile::exists(m_SphinxTrain))
+#endif
     {
       //SphinxTrain not found
       QString errorMsg = i18n("The SphinxTrain cannot be found. Please make sure it is installed correctly.");
@@ -126,14 +136,14 @@ bool ModelCompilerSPHINX::CompileLanguageModel()
 {
   kDebug() << "Compiling language model";
 
-  emit  status(i18n("Packing new language model to existing static acoustic model..."), 0, 100);
+  emit  status(i18nc("'Packing' in the sense of archiving", "Packing new language model to existing static acoustic model..."), 0, 100);
 
   //don't need to copy model to working dir, becouse we can just copy it to destination
   kDebug() << "Deploying model to destination";
 
   if(!pack(m_ModelDestination, m_ModelName))
   {
-    analyseError(i18n("Cannot copy model to destination"));
+    analyseError(i18n("Could not copy model to destination"));
     return false;
   }
 
@@ -166,7 +176,7 @@ bool ModelCompilerSPHINX::AdaptBaseModel()
 
   if(!generateAcousticFeatureFiles())
   {
-    analyseError(i18n("Cannot generate acoustic feature files"));
+    analyseError(i18n("Could not generate acoustic features"));
     return false;
   }
 
@@ -175,7 +185,7 @@ bool ModelCompilerSPHINX::AdaptBaseModel()
 
   if(!convertMdef())
   {
-    analyseError(i18n("Cannot convert mdef"));
+    analyseError(i18n("Could not convert mdef"));
     return false;
   }
 
@@ -184,7 +194,7 @@ bool ModelCompilerSPHINX::AdaptBaseModel()
 
   if(!getStatistics())
   {
-    analyseError(i18n("Cannot collect statistics from the adaptation data"));
+    analyseError(i18n("Could not collect statistics from the adaptation data"));
     return false;
   }
 
@@ -193,7 +203,7 @@ bool ModelCompilerSPHINX::AdaptBaseModel()
 
   if(!mapUpdate())
   {
-    analyseError(i18n("Cannot performing adaption with map method"));
+    analyseError(i18n("Could not perform adaption with \"map\" method"));
     return false;
   }
 
@@ -202,7 +212,7 @@ bool ModelCompilerSPHINX::AdaptBaseModel()
   kDebug() << "Сopying model to destination";
   if(!pack(m_ModelDestination, m_ModelName))
   {
-    analyseError(i18n("Cannot copy model to destination"));
+    analyseError(i18n("Could not copy model to destination"));
     return false;
   }
 
@@ -229,7 +239,7 @@ bool ModelCompilerSPHINX::CompileWholeModel()
 
   if(!setupModel(m_ModelDir, m_ModelName))
   {
-    analyseError(i18n("Cannot setup model"));
+    analyseError(i18n("Could not setup model"));
     return false;
   }
 
@@ -253,7 +263,7 @@ bool ModelCompilerSPHINX::CompileWholeModel()
 
   if(!modifyConfig(m_ConfigPath, params))
   {
-    analyseError(i18n("Cannot modify config at \"%1\"",m_ConfigPath));
+    analyseError(i18n("Could not modify config at \"%1\"",m_ConfigPath));
     return false;
   }
   if (!keepGoing) return false;
@@ -263,7 +273,7 @@ bool ModelCompilerSPHINX::CompileWholeModel()
 
   if(!compileModel(m_ModelDir, m_ModelName))
   {
-    analyseError(i18n("Cannot compile model"));
+    analyseError(i18n("Could not compile model"));
     return false;
   }
   if (!keepGoing) return false;
@@ -273,7 +283,7 @@ bool ModelCompilerSPHINX::CompileWholeModel()
 
   if(!pack(m_ModelDestination, m_ModelName))
   {
-    analyseError(i18n("Cannot copy model to destination"));
+    analyseError(i18n("Could not copy model to destination"));
     return false;
   }
 
@@ -287,16 +297,25 @@ bool ModelCompilerSPHINX::processError()
 {
   QString err = getBuildLog().trimmed();
 
-  int startIndex=0;
   //"WARNING: This phone (m=) occurs in the phonelist (.*phone), but not in the dictionary (.*dic)"
-  static QRegExp phonemeToPoison("WARNING: This phone \\((.*)\\) occurs in the phonelist .*, but not in the dictionary", Qt::CaseInsensitive);
+  static QRegExp phonemeToPoison("WARNING: This phone \\(([^)]*)\\) occurs in the phonelist .*, but not in", Qt::CaseInsensitive);
   if (phonemeToPoison.indexIn(err) != -1) {
     QString phoneme = phonemeToPoison.cap(1);
-    kDebug() << "Phoneme: " << phoneme;
+    kDebug() << "Phoneme is undefined: " << phoneme;
     emit phonemeUndefined(phoneme);
     return true;
   }
 
+  //check logdir/05.vector_quantize/<modelname>.kmeans.log for "Too few observations"
+  QString kmeansLogPath(m_ModelDir+QLatin1String("/")+m_ModelName+QLatin1String("/logdir/05.vector_quantize/")+m_ModelName+QLatin1String(".kmeans.log"));
+  if (QFile::exists(kmeansLogPath)) {
+    QFile log(kmeansLogPath);
+    log.open(QIODevice::ReadOnly);
+    log.readAll().contains("Too few observations");
+    emit error(i18n("Too little training material available.\n\nPlease train your acoustic model by recording samples."));
+    return true;
+  }
+
   return false;
 }
 
@@ -337,7 +356,8 @@ bool ModelCompilerSPHINX::pack(const QString &targetArchive, const QString &name
 
   if(!sourceDir.exists())
   {
-    analyseError(i18n("Failed to pack to archive. Source directory does not exist (\"%1\")", srcDirName));
+    //error will be reported by caller
+    //analyseError(i18n("Failed to pack to archive. Source directory does not exist (\"%1\")", srcDirName));
     return false;
   }
 
@@ -351,7 +371,7 @@ bool ModelCompilerSPHINX::pack(const QString &targetArchive, const QString &name
 
   QString fetc = m_ModelDir+QLatin1String("/")+m_ModelName+QLatin1String("/etc/")+m_ModelName;
   efm.insert(fetc+QLatin1String(".jsgf"), m_ModelName+QLatin1String(".jsgf"));
-  efm.insert(fetc+QLatin1String(".dic"), m_ModelName+QLatin1String(".dic"));
+  efm.insert(fetc+QLatin1String("_ship.dic"), m_ModelName+QLatin1String(".dic"));
 
   return FileUtils::pack(targetArchive, fm, efm);
 }
